@@ -77,9 +77,9 @@ struct chrono {
 public:
   chrono() { }
   void init() { cpu_=0; }
-  void tic() { t = float(::clock())/float(CLOCKS_PER_SEC); }
+  void tic() { t = float(gmm::uclock_sec()); }
   void toc() {
-    float t2 = float(::clock())/float(CLOCKS_PER_SEC);
+    float t2 = float(gmm::uclock_sec());
     cpu_ += t2 - t; t = t2;
   }
   float cpu() const { return cpu_; }
@@ -389,8 +389,8 @@ static void test_new_assembly(int N, int NX, int pK) {
   
   getfem::mesh m;
   
-  char Ns[5]; sprintf(Ns, "%d", N);
-  char Ks[5]; sprintf(Ks, "%d", pK);
+  char Ns[5]; snprintf(Ns, 5, "%d", N);
+  char Ks[5]; snprintf(Ks, 5, "%d", pK);
   bgeot::pgeometric_trans pgt =
     bgeot::geometric_trans_descriptor
     ((std::string("GT_PK(") + Ns + ",1)").c_str());
