@@ -1,6 +1,6 @@
 /*===========================================================================
 
- Copyright (C) 2004-2022 Julien Pommier.
+ Copyright (C) 2004-2025 Julien Pommier.
 
  This file is a part of GetFEM++
 
@@ -24,6 +24,10 @@
 #undef NDEBUG
 #endif
 
+#include <stdlib.h>
+#include <stdio.h>
+#include <errno.h>
+
 #include <Python.h>
 #include "numpy/arrayobject.h"
 #include "structmember.h"
@@ -34,15 +38,13 @@
 #include "getfem_arch_config.h"
 #include <assert.h>
 
-#if PY_MAJOR_VERSION >= 3
-#define PyString_AsString(o) PyUnicode_AsUTF8(o)
-#define PyString_FromFormat(a,b,c) PyUnicode_FromFormat(a,b,c)
-#define PyString_Check(o) PyUnicode_Check(o)
-#define PyInt_Check(o) PyLong_Check(o)
-#define PyInt_AsLong(o) PyLong_AsLong(o)
-#define PyString_FromString(o) PyUnicode_FromString(o)
-#define PyString_FromStringAndSize(o,l) PyUnicode_FromStringAndSize(o,l)
-#define PyInt_FromLong(o) PyLong_FromLong(o)
+#if PY_MAJOR_VERSION < 3
+#define PyUnicode_AsUTF8(o) PyString_AsString(o)
+#define PyUnicode_FromFormat(a,b,c) PyString_FromFormat(a,b,c)
+#define PyUnicode_Check(o) PyString_Check(o)
+#define PyUnicode_FromString(o) PyString_FromString(o)
+#define PyUnicode_FromStringAndSize(o,l) PyString_FromStringAndSize(o,l)
+#define PyLong_FromLong(o) PyInt_FromLong(o)
 #endif
 
 static PyObject *call_getfem(PyObject *self, PyObject *args);
@@ -63,8 +65,8 @@ typedef struct PyGetfemObject {
 
 static PyObject *
 GetfemObject_name(PyGetfemObject *self) {
-  return PyString_FromFormat("getfem.GetfemObject(classid=%d,objid=%d)",
-                             self->classid, self->objid);
+  return PyUnicode_FromFormat("getfem.GetfemObject(classid=%d,objid=%d)",
+                              self->classid, self->objid);
 }
 
 static int
@@ -139,7 +141,7 @@ static PyTypeObject PyGetfemObject_Type = {
     0,                                 /* tp_getattr */
     0,                                 /* tp_setattr */
 #if PY_MAJOR_VERSION >= 3
-    GetfemObject_compare,              /* tp_compare, necessary for dictionary*/
+    0,                                 /* tp_as_async */
 #else
     (cmpfunc)GetfemObject_compare,     /* tp_compare, necessary for dictionary*/
 #endif
@@ -333,32 +335,43 @@ static gfi_array *
 PyObject_to_gfi_array(gcollect *gc, PyObject *o)
 {
   gfi_object_id id;
-  gfi_array *t = gc_alloc(gc, sizeof(gfi_array)); if (!t) return NULL;
+  gfi_array *t = gc_alloc(gc, sizeof(gfi_array));
+  if (!t) return NULL;
 #define TGFISTORE0(T) t->storage.gfi_storage_u.data_##T
 #define TGFISTORE1(T,field) data_##T##_##field
 #define TGFISTORE(T,field) TGFISTORE0(T).TGFISTORE1(T,field)
   PyErr_Clear();
-  if (PyString_Check(o)) {
+  if (PyUnicode_Check(o)) {
     //printf("String\n");
     /* for strings, the pointer is shared, no copy */
-    int L = (int)(strlen(PyString_AsString(o)));
-    char *s = PyString_AsString(o);
-    gc_ref(gc, o, 0);
+    int L = (int)(strlen(PyUnicode_AsUTF8(o)));
+    const char *s = PyUnicode_AsUTF8(o);
 
     t->storage.type = GFI_CHAR;
-    t->dim.dim_len = 1; t->dim.dim_val = &TGFISTORE(char,len);
+    t->dim.dim_len = 1;
+    t->dim.dim_val = &TGFISTORE(char,len);
     TGFISTORE(char,len)=L;
-    TGFISTORE(char,val)=s;
+    if (!(TGFISTORE(char,val)=gc_alloc(gc,L*sizeof(char)))) return NULL;
+    memcpy(TGFISTORE(char,val), s, L);
+#if PY_MAJOR_VERSION < 3
   } else if (PyInt_Check(o) || PyLong_Check(o)) {
+#else
+  } else if (PyLong_Check(o)) {
+#endif
     //printf("Int or Long\n");
     /* usual python integer */
+#if PY_MAJOR_VERSION < 3
     int d = (int)PyInt_AsLong(o);
+#else
+    int d = (int)PyLong_AsLong(o);
+#endif
     if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_OverflowError))
       return (gfi_array *)PyErr_Format(PyExc_OverflowError,
                                        "in getfem interface.");
 
     t->storage.type = GFI_INT32;
-    t->dim.dim_len = 0; t->dim.dim_val = &TGFISTORE(int32,len);
+    t->dim.dim_len = 0;
+    t->dim.dim_val = &TGFISTORE(int32,len);
     TGFISTORE(int32,len)=1;
     if (!(TGFISTORE(int32,val)=gc_alloc(gc,sizeof(int)))) return NULL;
     TGFISTORE(int32,val)[0] = d;
@@ -367,7 +380,8 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
     /* usual python float */
     double df = PyFloat_AsDouble(o);
     t->storage.type = GFI_DOUBLE;
-    t->dim.dim_len = 0; t->dim.dim_val = &TGFISTORE(double,len);
+    t->dim.dim_len = 0;
+    t->dim.dim_val = &TGFISTORE(double,len);
     TGFISTORE(double,len)=1;
     t->storage.gfi_storage_u.data_double.is_complex = 0;
     if (!(TGFISTORE(double,val)=gc_alloc(gc,sizeof(double)))) return NULL;
@@ -378,7 +392,8 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
     double real = PyComplex_RealAsDouble(o);
     double imag = PyComplex_ImagAsDouble(o);
     t->storage.type = GFI_DOUBLE;
-    t->dim.dim_len = 0; t->dim.dim_val = &TGFISTORE(double,len);
+    t->dim.dim_len = 0;
+    t->dim.dim_val = &TGFISTORE(double,len);
     TGFISTORE(double,len)=2;
     t->storage.gfi_storage_u.data_double.is_complex = 1;
     if (!(TGFISTORE(double,val)=gc_alloc(gc,sizeof(double)*2))) return NULL;
@@ -464,7 +479,7 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
       default: {
         PyObject *sdtype =PyObject_Str((PyObject*)PyArray_DescrFromType(dtype));
         PyErr_Format(PyExc_RuntimeError, "invalid numeric dtype: %s",
-          PyString_AsString(sdtype));
+                     PyUnicode_AsUTF8(sdtype));
         Py_DECREF(sdtype);
         return NULL;
       }
@@ -472,16 +487,15 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
     t->dim.dim_len = PyArray_NDIM((PyArrayObject *)po);
     t->dim.dim_val = (u_int *)gc_alloc(gc, t->dim.dim_len * sizeof(u_int));
 
-    int i;
-    for (i=0; i < t->dim.dim_len; ++i)
+    for (u_int i=0; i < t->dim.dim_len; ++i)
       t->dim.dim_val[i] = (u_int)PyArray_DIM((PyArrayObject *)po,i);
   } else if (PyTuple_Check(o) || PyList_Check(o)) {
     //printf("Tuple or List\n");
     /* python tuples and lists are stored in 'cell arrays'
        (i.e. matlab's lists of inhomogeneous elements) */
-    int i;
     t->storage.type = GFI_CELL;
-    t->dim.dim_len = 1; t->dim.dim_val = &TGFISTORE(cell,len);
+    t->dim.dim_len = 1;
+    t->dim.dim_val = &TGFISTORE(cell,len);
 
     if (PyTuple_Check(o)) TGFISTORE(cell,len) = (unsigned)(PyTuple_GET_SIZE(o));
     else TGFISTORE(cell,len) = (unsigned)(PyList_GET_SIZE(o));
@@ -490,7 +504,7 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
           = gc_alloc(gc,sizeof(gfi_array*)*TGFISTORE(cell,len)))) return NULL;
     gfi_array **p = TGFISTORE(cell,val);
 
-    for (i=0; i < TGFISTORE(cell,len); ++i) {
+    for (u_int i=0; i < TGFISTORE(cell,len); ++i) {
       if (PyTuple_Check(o))
         p[i] = PyObject_to_gfi_array(gc, PyTuple_GET_ITEM(o,i));
       else p[i] = PyObject_to_gfi_array(gc, PyList_GET_ITEM(o,i));
@@ -500,7 +514,8 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
     //printf("Object\n");
     /* getfem objects are refered to with a couple (classid, objectid) */
     t->storage.type = GFI_OBJID;
-    t->dim.dim_len = 1; t->dim.dim_val = &TGFISTORE(cell,len);
+    t->dim.dim_len = 1;
+    t->dim.dim_val = &TGFISTORE(cell,len);
     t->storage.gfi_storage_u.objid.objid_len = 1;
     if (!(t->storage.gfi_storage_u.objid.objid_val =
           gc_alloc(gc,sizeof(gfi_object_id)))) return NULL;
@@ -511,7 +526,7 @@ PyObject_to_gfi_array(gcollect *gc, PyObject *o)
     PyObject *sdtype = PyObject_Str((PyObject*)PyArray_DescrFromType(dtype));
     PyErr_Format(PyExc_RuntimeError,
                  "unhandled argument (type, dtype): (%s, %s)",
-                 PyString_AsString(stype), PyString_AsString(sdtype));
+                 PyUnicode_AsUTF8(stype), PyUnicode_AsUTF8(sdtype));
     Py_DECREF(stype);
     Py_DECREF(sdtype);
     return NULL;
@@ -532,7 +547,7 @@ PyGetfemObject_FromObjId(gfi_object_id id, int in__init__) {
     PyObject *arg;
     if (!(arg = Py_BuildValue("(O)", go))) return NULL;
     //printf("  -> arg= "); PyObject_Print(arg,stdout,0); printf("\n");
-    o = PyEval_CallObject(python_factory, arg);
+    o = PyObject_CallObject(python_factory, arg);
     Py_DECREF(arg);
   } else o = (PyObject*)go;
   //printf("  -> return "); PyObject_Print(o,stdout,0); printf("\n");
@@ -540,18 +555,18 @@ PyGetfemObject_FromObjId(gfi_object_id id, int in__init__) {
 }
 
 static const gfi_array **
-build_gfi_array_list(gcollect *gc, PyObject *tuple, char **pfunction_name,
+build_gfi_array_list(gcollect *gc, PyObject *tuple, const char **pfunction_name,
                      int *nb) {
   const gfi_array **l;
   int i, j;
   if (PyTuple_GET_SIZE(tuple) == 0) {
     PyErr_SetString(PyExc_RuntimeError, "missing function name"); return NULL;
   }
-  if (!PyString_Check(PyTuple_GET_ITEM(tuple,0))) {
+  if (!PyUnicode_Check(PyTuple_GET_ITEM(tuple,0))) {
     PyErr_SetString(PyExc_RuntimeError, "expecting function name as a string");
     return NULL;
   }
-  *pfunction_name = PyString_AsString(PyTuple_GET_ITEM(tuple,0));
+  *pfunction_name = PyUnicode_AsUTF8(PyTuple_GET_ITEM(tuple,0));
   *nb = (int)(PyTuple_GET_SIZE(tuple) - 1);
   if (!(l = gc_alloc(gc, sizeof(gfi_array*) * *nb))) return NULL;
   for (i=0, j = 0; i < *nb; ++i) {
@@ -573,13 +588,14 @@ gfi_array_to_PyObject(gfi_array *t, int in__init__) {
   case GFI_UINT32:
   case GFI_INT32: {
     //printf("GFI_INT32\n");
-    if (t->dim.dim_len == 0) return PyInt_FromLong(TGFISTORE(int32,val)[0]);
+    if (t->dim.dim_len == 0)
+      return PyLong_FromLong(TGFISTORE(int32,val)[0]);
     else {
       npy_intp *dim = PyDimMem_NEW(t->dim.dim_len);
-      int i;
-      for(i=0; i < t->dim.dim_len; i++)
+      for (u_int i=0; i < t->dim.dim_len; i++)
         dim[i] = (npy_intp)t->dim.dim_val[i];
-      if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_INT, 1))) return NULL;
+      if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_INT, 1)))
+        return NULL;
       PyDimMem_FREE(dim);
 
       npy_intp itemsize = PyArray_ITEMSIZE((PyArrayObject *)o);
@@ -595,8 +611,7 @@ gfi_array_to_PyObject(gfi_array *t, int in__init__) {
         return PyFloat_FromDouble(TGFISTORE(double,val)[0]);
       else {
         npy_intp *dim = PyDimMem_NEW(t->dim.dim_len);
-        int i;
-        for(i=0; i< t->dim.dim_len; i++)
+        for (u_int i=0; i < t->dim.dim_len; i++)
           dim[i] = (npy_intp)t->dim.dim_val[i];
         if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_DOUBLE, 1)))
           return NULL;
@@ -608,8 +623,7 @@ gfi_array_to_PyObject(gfi_array *t, int in__init__) {
                                      TGFISTORE(double,val)[1]);
       else {
         npy_intp *dim = PyDimMem_NEW(t->dim.dim_len);
-        int i;
-        for(i=0; i< t->dim.dim_len; i++)
+        for (u_int i=0; i < t->dim.dim_len; i++)
           dim[i] = (npy_intp)t->dim.dim_val[i];
         if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_CDOUBLE, 1)))
           return NULL;
@@ -623,13 +637,12 @@ gfi_array_to_PyObject(gfi_array *t, int in__init__) {
   } break;
   case GFI_CHAR: {
     //printf("GFI_CHAR\n");
-    o = PyString_FromStringAndSize(TGFISTORE(char,val),TGFISTORE(char,len));
+    o = PyUnicode_FromStringAndSize(TGFISTORE(char,val),TGFISTORE(char,len));
   } break;
   case GFI_CELL: {
     //printf("GFI_CELL\n");
-    unsigned i;
     if (!(o = PyTuple_New(TGFISTORE(cell,len)))) return NULL;
-    for (i=0; i < TGFISTORE(cell,len); ++i) {
+    for (u_int i=0; i < TGFISTORE(cell,len); ++i) {
       PyObject *to = gfi_array_to_PyObject(TGFISTORE(cell,val)[i], in__init__);
       if (!to) return NULL;
       PyTuple_SET_ITEM(o,i,to);
@@ -642,11 +655,10 @@ gfi_array_to_PyObject(gfi_array *t, int in__init__) {
 #if 0
       /* PyArray_OBJECT is not supported in numarray ... */
       npy_intp *dim = PyDimMem_NEW(t->dim.dim_len);
-      int i;
-      for(i=0; i< t->dim.dim_len; i++)
+      for (u_int i=0; i < t->dim.dim_len; i++)
         dim[i] = (npy_intp)t->dim.dim_val[i];
-      if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_OBJECT,1))) return NULL;
-
+      if (!(o = PyArray_EMPTY(t->dim.dim_len, dim, NPY_OBJECT,1)))
+        return NULL;
       if (!PyArray_ISFARRAY(PyArray_DATA((PyArrayObject *)o))) {
         // I'm just too lazy to transpose matrices
         PyErr_Format(PyExc_RuntimeError,
@@ -700,7 +712,8 @@ call_getfem_(PyObject *self, PyObject *args, int in__init__)
   const gfi_array **in = 0;
   gfi_array **out = 0;
   int in_cnt = 0, out_cnt = -1;
-  char *function_name, *infomsg, *errmsg;
+  const char *function_name;
+  char *infomsg, *errmsg;
   gcollect gc;
   PyObject *result = NULL;
   gc.allocated = gc.pyobjects = NULL;
@@ -730,7 +743,11 @@ call_getfem_(PyObject *self, PyObject *args, int in__init__)
         result = Py_None; Py_INCREF(Py_None);
       } else if (out) {
         int i, err = 0;
+#if defined(_MSC_VER)
+        PyObject **d = (PyObject **)malloc(out_cnt*sizeof(PyObject*));
+#else
         PyObject *d[out_cnt];
+#endif
         for (i = 0; i < out_cnt; ++i) {
           if (!err && !(d[i] = gfi_array_to_PyObject(out[i], in__init__)))
             err = 1;
@@ -744,6 +761,9 @@ call_getfem_(PyObject *self, PyObject *args, int in__init__)
             for (i = 0; i < out_cnt; ++i) PyTuple_SET_ITEM(result,i,d[i]);
           } else result = d[0];
         }
+#if defined(_MSC_VER)
+        free(d);
+#endif
       }
     }
   }
@@ -775,32 +795,30 @@ getfem_env(PyObject *self, PyObject *args) {
   PyObject* word_out;
 
   if (strcmp(word_in,"project") == 0) {
-    word_out = PyString_FromString("GetFEM");
+    word_out = PyUnicode_FromString("GetFEM");
   } else if (strcmp(word_in,"copyright") == 0) {
-    word_out = PyString_FromString
-    ("2004-2022 GetFEM project");
+    word_out = PyUnicode_FromString
+    ("2004-2025 GetFEM project");
   } else if (strcmp(word_in,"authors") == 0) {
-    word_out = PyString_FromString
+    word_out = PyUnicode_FromString
     ("Yves Renard, Julien Pommier, Konstantinos Poulios");
   } else if (strcmp(word_in,"url") == 0) {
-    word_out = PyString_FromString("http://home.gna.org/getfem/");
+    word_out = PyUnicode_FromString("http://home.gna.org/getfem/");
   } else if (strcmp(word_in,"license") == 0) {
-    word_out = PyString_FromString("GNU LGPL v3");
-  } else if (strcmp(word_in,"package") == 0) {
-    word_out = PyString_FromString(GETFEM_PACKAGE);
-  } else if (strcmp(word_in,"package_name") == 0) {
-    word_out = PyString_FromString(GETFEM_PACKAGE_NAME);
+    word_out = PyUnicode_FromString("GNU LGPL v3");
+  } else if (strcmp(word_in,"package") == 0 ||
+             strcmp(word_in,"package_name") == 0) {
+    word_out = PyUnicode_FromString(GETFEM_PACKAGE_NAME);
   } else if (strcmp(word_in,"package_string") == 0) {
-    word_out = PyString_FromString(GETFEM_PACKAGE_STRING);
-  } else if(strcmp(word_in,"package_tarname") == 0) {
-    word_out = PyString_FromString(GETFEM_PACKAGE_TARNAME);
-  } else if(strcmp(word_in,"package_version") == 0 ||
-            strcmp(word_in,"release") == 0) {
-    word_out = PyString_FromString(GETFEM_PACKAGE_VERSION);
-  } else if(strcmp(word_in,"version") == 0) {
-    word_out = PyString_FromString(GETFEM_VERSION);
+    word_out = PyUnicode_FromString(GETFEM_PACKAGE_STRING);
+  } else if (strcmp(word_in,"package_tarname") == 0) {
+    word_out = PyUnicode_FromString(GETFEM_PACKAGE_TARNAME);
+  } else if (strcmp(word_in,"package_version") == 0 ||
+             strcmp(word_in,"release") == 0 ||
+             strcmp(word_in,"version") == 0) {
+    word_out = PyUnicode_FromString(GETFEM_VERSION);
   } else {
-    word_out = PyString_FromString("");
+    word_out = PyUnicode_FromString("");
   }
 
   Py_INCREF(word_out);
