@@ -32,7 +32,7 @@
     @author Yves Renard <Yves.Renard@insa-lyon.fr>
     @date   November 18, 2013.
     @brief  Definition of the syntax tree and basic operations on it.
-            Internal header for the generic assembly language part. 
+            Internal header for the generic assembly language part.
  */
 
 
@@ -212,7 +212,7 @@ namespace getfem {
     ga_throw_error_msg(expr, pos, ss.str());          \
     GMM_ASSERT1(false, "Error in assembly string" );  \
   }
-  
+
   // Structure for the tensor associated with a tree node
   struct assembly_tensor {
     bool is_copied;
@@ -221,29 +221,24 @@ namespace getfem {
     base_tensor t;
     assembly_tensor *tensor_copied;
 
-    const base_tensor &org_tensor() const
-    { return is_copied ? tensor_copied->org_tensor() : t; }
-    base_tensor &org_tensor()
-    { return is_copied ? tensor_copied->org_tensor() : t; }
-
     const base_tensor &tensor() const
     { return (is_copied ? tensor_copied->tensor() : t); }
-
     base_tensor &tensor()
     { return (is_copied ? tensor_copied->tensor() : t); }
 
     void set_sparsity(int sp, size_type q)
     { sparsity_ = sp; qdim_ = q; }
 
-    size_type qdim() { return is_copied ? tensor_copied->qdim() : qdim_; }
+    size_type qdim() const { return is_copied ? tensor_copied->qdim() : qdim_; }
 
     int sparsity() const
     { return is_copied ? tensor_copied->sparsity() : sparsity_; }
 
     inline void set_to_original() { is_copied = false; }
+
     inline void set_to_copy(assembly_tensor &t_) {
       is_copied = true; sparsity_ = t_.sparsity_; qdim_ = t_.qdim_;
-      t = t_.org_tensor(); tensor_copied = &(t_);
+      t = t_.tensor(); tensor_copied = &(t_);
     }
 
     inline void adjust_sizes(const bgeot::multi_index &ssizes)
@@ -305,7 +300,7 @@ namespace getfem {
   struct ga_tree_node;
   typedef ga_tree_node *pga_tree_node;
 
-  
+
   struct ga_tree_node {
     GA_NODE_TYPE node_type;
     GA_TOKEN_TYPE op_type;
@@ -331,7 +326,7 @@ namespace getfem {
     std::string elementary_name;  // For Elementary_transformation :
                                   // name of transformation
     std::string elementary_target;// For Elementary_transformation :
-                                  // target variable (for its mesh_fem) 
+                                  // target variable (for its mesh_fem)
     size_type der1, der2;         // For functions and nonlinear operators,
                                   // optional derivative or second derivative.
     bool symmetric_op;
@@ -358,7 +353,7 @@ namespace getfem {
     }
 
     inline size_type tensor_proper_size() const
-    { return t.org_tensor().size() / tensor_test_size(); }
+    { return t.tensor().size() / tensor_test_size(); }
 
     inline size_type tensor_proper_size(size_type i) const
     { return t.sizes()[nb_test_functions()+i]; }
@@ -378,7 +373,7 @@ namespace getfem {
       return (node_type == GA_NODE_CONSTANT ||
               (node_type == GA_NODE_ZERO && test_function_type == 0));
     }
-    
+
     inline void init_scalar_tensor(scalar_type v)
     { t.init_scalar_tensor(v); test_function_type = 0; }
 
@@ -401,6 +396,11 @@ namespace getfem {
     inline void adopt_child(pga_tree_node new_child)
     { children.push_back(new_child); children.back()->parent = this; }
 
+    inline void accept_child(size_type i) {
+      GMM_ASSERT1(i < children.size(), "Internal error");
+      children[i]->parent = this;
+    }
+
     inline void replace_child(pga_tree_node oldchild,
                               pga_tree_node newchild) {
         bool found = false;
@@ -453,8 +453,7 @@ namespace getfem {
     void clear() { clear_node_rec(root); root = current_node = nullptr; }
     void clear_children(pga_tree_node pnode);
     void replace_node_by_child(pga_tree_node pnode, size_type i);
-    void copy_node(pga_tree_node pnode, pga_tree_node parent,
-                   pga_tree_node &child);
+    void copy_node(pga_tree_node pnode, pga_tree_node &pnode_new);
     void duplicate_with_operation(pga_tree_node pnode, GA_TOKEN_TYPE op_type);
     void duplicate_with_addition(pga_tree_node pnode)
     { duplicate_with_operation(pnode, GA_PLUS); }
@@ -470,14 +469,19 @@ namespace getfem {
 
     ga_tree() : root(nullptr), current_node(nullptr), secondary_domain() {}
 
-    ga_tree(const ga_tree &tree) : root(nullptr), current_node(nullptr),
-      secondary_domain(tree.secondary_domain)
-    { if (tree.root) copy_node(tree.root, nullptr, root); }
+    ga_tree(const ga_tree &tree)
+      : root(nullptr), current_node(nullptr),
+        secondary_domain(tree.secondary_domain)
+    {
+      if (tree.root)
+        copy_node(tree.root, root);
+    }
 
     ga_tree &operator =(const ga_tree &tree) {
-      clear(); secondary_domain = tree.secondary_domain;
+      clear();
+      secondary_domain = tree.secondary_domain;
       if (tree.root)
-        copy_node(tree.root,nullptr,root);
+        copy_node(tree.root, root);
       return *this;
     }
 
@@ -494,8 +498,7 @@ namespace getfem {
 
   // Transform the expression of a node and its sub-nodes in the equivalent
   // assembly string sent to ostream str
-  void ga_print_node(const pga_tree_node pnode,
-                     std::ostream &str);
+  void ga_print_node(const pga_tree_node pnode, std::ostream &str);
   // The same for the whole tree, the result is a std::string
   std::string ga_tree_to_string(const ga_tree &tree);
 
