@@ -77,6 +77,8 @@ namespace getfem {
 
   static scalar_type ga_Heaviside(scalar_type t) { return (t >= 0.) ? 1.: 0.; }
   static scalar_type ga_pos_part(scalar_type t) { return (t >= 0.) ? t : 0.; }
+  static scalar_type ga_sqr_pos_part(scalar_type t)
+  { return (t >= 0.) ? t*t : 0.; }
   static scalar_type ga_reg_pos_part(scalar_type t, scalar_type eps)
   { return (t >= eps) ? t-eps/2. : ((t <= 0) ? 0. : t*t/(2.*eps)); }
   static scalar_type ga_der_reg_pos_part(scalar_type t, scalar_type eps)
@@ -88,6 +90,8 @@ namespace getfem {
   static scalar_type ga_half_sqr_pos_part(scalar_type t)
   { return (t >= 0.) ? 0.5*t*t : 0.; }
   static scalar_type ga_neg_part(scalar_type t) { return (t >= 0.) ? 0. : -t; }
+  static scalar_type ga_sqr_neg_part(scalar_type t)
+  { return (t >= 0.) ? 0. : t*t; }
   static scalar_type ga_half_sqr_neg_part(scalar_type t)
   { return (t >= 0.) ? 0. : 0.5*t*t; }
   static scalar_type ga_sinc(scalar_type t) {// cardinal sine function sin(t)/t
@@ -507,10 +511,14 @@ namespace getfem {
     PREDEF_FUNCTIONS["abs"] = ga_predef_function(ga_abs, 1, "sign");
     PREDEF_FUNCTIONS["pos_part"]
       = ga_predef_function(ga_pos_part, 1, "Heaviside");
+    PREDEF_FUNCTIONS["sqr_pos_part"]
+      = ga_predef_function(ga_sqr_pos_part, 2, "2*pos_part(t)");
     PREDEF_FUNCTIONS["half_sqr_pos_part"]
       = ga_predef_function(ga_half_sqr_pos_part, 1, "pos_part");
     PREDEF_FUNCTIONS["neg_part"]
       = ga_predef_function(ga_neg_part, 1, "DER_PDFUNC_NEG_PART");
+    PREDEF_FUNCTIONS["sqr_neg_part"]
+      = ga_predef_function(ga_sqr_neg_part, 2, "-2*neg_part(t)");
     PREDEF_FUNCTIONS["half_sqr_neg_part"]
       = ga_predef_function(ga_half_sqr_neg_part, 2, "-neg_part(t)");
     PREDEF_FUNCTIONS["reg_pos_part"]
