@@ -431,17 +431,20 @@ namespace getfem {
       if (sibling != child) clear_node_rec(sibling);
     delete pnode;
   }
-  
-  void ga_tree::copy_node(pga_tree_node pnode, pga_tree_node parent,
-                          pga_tree_node &child) {
-    GMM_ASSERT1(child == nullptr, "Internal error");
-    child = new ga_tree_node();
-    *child = *pnode;
-    child->parent = parent;
-    for (pga_tree_node &grandchild : child->children)
-      grandchild = nullptr;
-    for (size_type j = 0; j < child->children.size(); ++j)
-      copy_node(pnode->children[j], child, child->children[j]);
+
+  // This function allocates a new node "pnode_new", copies the content of "pnode"
+  // into the newly allocated node (including deep copies of all of its children)
+  void ga_tree::copy_node(pga_tree_node pnode,
+                          pga_tree_node &pnode_new) {
+    GMM_ASSERT1(pnode_new == nullptr, "Internal error");
+    pnode_new = new ga_tree_node();
+    *pnode_new = *pnode;
+    pnode_new->parent = nullptr;
+    for (size_type j = 0; j < pnode_new->children.size(); ++j) {
+      pnode_new->children[j] = nullptr;
+      copy_node(pnode->children[j], pnode_new->children[j]);
+      pnode_new->accept_child(j);
+    }
   }
   
   void ga_tree::duplicate_with_operation(pga_tree_node pnode,
@@ -456,7 +459,8 @@ namespace getfem {
     else
       root = newop;
     pnode->parent = newop;
-    copy_node(pnode, newop, newop->children[1]);
+    copy_node(pnode, newop->children[1]);
+    newop->accept_child(1);
   }
 
   void ga_tree::add_child(pga_tree_node pnode, GA_NODE_TYPE node_type) {
@@ -538,12 +542,12 @@ namespace getfem {
           return false;
       break;
     case GA_NODE_C_MATRIX:
-      if (pnode1->children.size() != pnode2->children.size()) return false;
-      if (pnode1->nb_test_functions() != pnode2->nb_test_functions())
+      if (pnode1->children.size() != pnode2->children.size() ||
+          pnode1->nb_test_functions() != pnode2->nb_test_functions() ||
+          pnode1->t.sizes().size() != pnode2->t.sizes().size())
         return false;
-      if (pnode1->t.sizes().size() != pnode2->t.sizes().size()) return false;
       for (size_type i=pnode1->nb_test_functions();
-           i<pnode1->t.sizes().size(); ++i)
+           i < pnode1->t.sizes().size(); ++i)
         if (pnode1->t.sizes()[i] != pnode2->t.sizes()[i]) return false;
       if (pnode1->nbc1 != pnode2->nbc1) return false;
       break;
@@ -780,8 +784,7 @@ namespace getfem {
     GMM_ASSERT1(pnode->children.size() == 0, "Invalid tree");
   }
 
-  void ga_print_node(const pga_tree_node pnode,
-                            std::ostream &str) {
+  void ga_print_node(const pga_tree_node pnode, std::ostream &str) {
     if (!pnode) return;
     long prec = str.precision(16);
 
@@ -1355,8 +1358,8 @@ namespace getfem {
   (ga_tree &tree, pga_tree_node pnode,
    const std::vector<pga_tree_node> &children) {
     if (!pnode) return;
-    for (size_type i = 0; i < pnode->children.size(); ++i)
-      ga_replace_macro_params(tree, pnode->children[i], children);
+    for (pga_tree_node &child : pnode->children)
+      ga_replace_macro_params(tree, child, children);
     
     if (pnode->node_type == GA_NODE_MACRO_PARAM) {
       size_type po = pnode->nbc2;
@@ -1391,7 +1394,8 @@ namespace getfem {
       } else {
         pga_tree_node pnode_old = pnode;
         pnode = nullptr;
-        tree.copy_node(pchild, pnode_old->parent, pnode);
+        tree.copy_node(pchild, pnode);
+        pnode->parent = pnode_old->parent;
         if (pnode_old->parent)
           pnode_old->parent->replace_child(pnode_old, pnode);
         else
@@ -1407,7 +1411,7 @@ namespace getfem {
     if (!pnode) return;
     
     if (pnode->node_type == GA_NODE_PARAMS) {
-      
+
       for (size_type i = 1; i < pnode->children.size(); ++i)
         ga_expand_macro(tree, pnode->children[i], macro_dict);
 
@@ -1422,8 +1426,8 @@ namespace getfem {
           if (gam.nb_params()==0) { // Macro without parameters
             pga_tree_node pnode_old = pnode->children[0];
             pnode->children[0] = nullptr;
-            tree.copy_node(gam.tree().root,
-                           pnode_old->parent,pnode->children[0]);
+            tree.copy_node(gam.tree().root, pnode->children[0]);
+            pnode->children[0]->parent = pnode_old->parent;
             GMM_ASSERT1(pnode_old->children.empty(), "Internal error");
             delete pnode_old;
           } else { // Macro with parameters
@@ -1435,7 +1439,8 @@ namespace getfem {
 
             pga_tree_node pnode_old = pnode;
             pnode = nullptr;
-            tree.copy_node(gam.tree().root, pnode_old->parent, pnode);
+            tree.copy_node(gam.tree().root, pnode);
+            pnode->parent = pnode_old->parent;
             if (pnode_old->parent)
               pnode_old->parent->replace_child(pnode_old, pnode);
             else
@@ -1458,7 +1463,8 @@ namespace getfem {
 
       pga_tree_node pnode_old = pnode;
       pnode = nullptr;
-      tree.copy_node(gam.tree().root, pnode_old->parent, pnode);
+      tree.copy_node(gam.tree().root, pnode);
+      pnode->parent = pnode_old->parent;
       if (pnode_old->parent)
         pnode_old->parent->replace_child(pnode_old, pnode);
       else
@@ -1466,16 +1472,16 @@ namespace getfem {
       GMM_ASSERT1(pnode_old->children.empty(), "Internal error");
       delete pnode_old;
     } else {
-      for (size_type i = 0; i < pnode->children.size(); ++i)
-        ga_expand_macro(tree, pnode->children[i], macro_dict);
+      for (pga_tree_node &child : pnode->children)
+        ga_expand_macro(tree, child, macro_dict);
     }
   }
 
   static void ga_mark_macro_params_rec(const pga_tree_node pnode,
                                        const std::vector<std::string> &params) {
     if (!pnode) return;
-    for (size_type i = 0; i < pnode->children.size(); ++i)
-      ga_mark_macro_params_rec(pnode->children[i], params);
+    for (pga_tree_node &child : pnode->children)
+      ga_mark_macro_params_rec(child, params);
     
     if (pnode->node_type == GA_NODE_NAME ||
         pnode->node_type == GA_NODE_INTERPOLATE ||
@@ -1707,7 +1713,7 @@ namespace getfem {
             if (t_type != GA_NAME)
               ga_throw_error(expr, pos,
                              "First argument of Interpolate should the "
-                             "interpolate transformtion name ");
+                             "interpolate transformation name ");
             tree.current_node->interpolate_name_der
               = std::string(&((*expr)[token_pos]), token_length);
             t_type = ga_get_token(*expr, pos, token_pos, token_length);
@@ -1945,7 +1951,8 @@ namespace getfem {
                   mi.pop_back();
                   sub_tree.root->tensor().adjust_sizes(mi);
                 }
-                if (!nb_comp) mii = sub_tree.root->tensor().sizes();
+                if (!nb_comp)
+                  mii = sub_tree.root->tensor().sizes();
                 else {
                   const bgeot::multi_index &mi=sub_tree.root->tensor().sizes();
                   bool cmp = true;
@@ -1957,10 +1964,9 @@ namespace getfem {
                     ga_throw_error(expr, pos-1, "Bad explicit "
                                    "vector/matrix/tensor format.");
                 }
-                for (size_type i = 0; i < sub_tree.root->children.size(); ++i) {
-                  sub_tree.root->children[i]->parent = tree.current_node;
-                  tree.current_node->children.push_back
-                    (sub_tree.root->children[i]);
+                for (pga_tree_node &child : sub_tree.root->children) {
+                  child->parent = tree.current_node;
+                  tree.current_node->children.push_back(child);
                 }
                 sub_tree.root->children.resize(0);
                 nb_comp++;
@@ -2029,23 +2035,32 @@ namespace getfem {
 
               } while (r_type != GA_RBRACKET);
               bgeot::multi_index mi;
-              nbc1 = tree.current_node->nbc1; nbc2 = tree.current_node->nbc2;
+              nbc1 = tree.current_node->nbc1;
+              nbc2 = tree.current_node->nbc2;
               nbc3 = tree.current_node->nbc3;
 
               size_type nbl = tree.current_node->children.size()
                 / (nbc2 * nbc1 * nbc3);
               switch(tensor_order) {
               case 1:
-                /* mi.push_back(1); */ mi.push_back(nbc1); break;
+                // mi.push_back(1);
+                mi.push_back(nbc1);
+                break;
               case 2:
-                mi.push_back(nbl); if (nbc1 > 1) mi.push_back(nbc1); break;
+                mi.push_back(nbl);
+                if (nbc1 > 1)
+                  mi.push_back(nbc1);
+                break;
               case 3:
-                mi.push_back(nbl); mi.push_back(nbc2);
+                mi.push_back(nbl);
+                mi.push_back(nbc2);
                 mi.push_back(nbc1);
                 break;
               case 4:
-                mi.push_back(nbl); mi.push_back(nbc3);
-                mi.push_back(nbc2); mi.push_back(nbc1);
+                mi.push_back(nbl);
+                mi.push_back(nbc3);
+                mi.push_back(nbc2);
+                mi.push_back(nbc1);
                 break;
               default: GMM_ASSERT1(false, "Internal error");
               }
@@ -2075,10 +2090,12 @@ namespace getfem {
         case GA_COLON: case GA_DOT: case GA_DOTMULT: case GA_DOTDIV:
         case GA_TMULT:
           tree.add_op(t_type, token_pos, expr);
-          state = 1; break;
+          state = 1;
+          break;
         case GA_QUOTE:
           tree.add_op(t_type, token_pos, expr);
-          state = 2; break;
+          state = 2;
+          break;
         case GA_END: case GA_RPAR: case GA_COMMA: case GA_DCOMMA:
         case GA_RBRACKET: case GA_SEMICOLON: case GA_DSEMICOLON:
           return t_type;
@@ -2123,10 +2140,17 @@ namespace getfem {
     if (tree.root) ga_expand_macro(tree, tree.root, macro_dict);
     
     switch (t) {
-    case GA_RPAR: ga_throw_error(nexpr, pos-1, "Unbalanced parenthesis.");
-    case GA_RBRACKET: ga_throw_error(nexpr, pos-1, "Unbalanced braket.");
-    case GA_END: break;
-    default: ga_throw_error(nexpr, pos-1, "Unexpected token.");
+    case GA_RPAR:
+      ga_throw_error(nexpr, pos-1, "Unbalanced parenthesis.");
+      break;
+    case GA_RBRACKET:
+      ga_throw_error(nexpr, pos-1, "Unbalanced bracket.");
+      break;
+    case GA_END:
+      break;
+    default:
+      ga_throw_error(nexpr, pos-1, "Unexpected token.");
+      break;
     }
   }
   
