@@ -138,7 +138,7 @@ namespace getfem {
                       "Exact integration not allowed in this context");
 
           if ((*it).t != GETFEM_NONLINEAR_ && !((*it).pfi->is_equivalent())) {
-            // TODO : le numero d'indice  reduire peut changer ...
+            // TODO : le numero d'indice à reduire peut changer ...
             trans_reduction.push_back(k);
             trans_reduction_pfi.push_back((*it).pfi);
           }
@@ -151,7 +151,7 @@ namespace getfem {
               case virtual_fem::VECTORIAL_PRIMAL_TYPE:
                 K_reduction.push_back(k); break;
               case virtual_fem::VECTORIAL_DUAL_TYPE:
-                grad_reduction.push_back(k); break;
+                grad_reduction.push_back(k); break; // reduction with B
               default: break;
               }
             }
@@ -167,7 +167,7 @@ namespace getfem {
             case virtual_fem::VECTORIAL_PRIMAL_TYPE:
               K_reduction.push_back(k); break;
             case virtual_fem::VECTORIAL_DUAL_TYPE:
-              grad_reduction.push_back(k); break;
+              grad_reduction.push_back(k); break; // reduction with B
             default: break;
             }
             if ((*it).pfi->target_dim() > 1) ++k;
@@ -386,32 +386,43 @@ namespace getfem {
       es_end.resize(0); es_end.resize(pme->size());
       Vtab.resize(pme->size());
       size_type nm = 0;
-      if (first) memset(&(*t.begin()), 0, t.size()*sizeof(*t.begin())); //std::fill(t.begin(), t.end(), 0.0);
+      if (first)
+        memset(&(*t.begin()), 0, t.size()*sizeof(*t.begin())); //std::fill(t.begin(), t.end(), 0.0);
       for (k = 0, nm = 0; k < pme->size(); ++k) {
         if (elmt_stored[k].size() != 1) {
           es_beg[nm] = elmt_stored[k].begin();
           es_end[nm] = elmt_stored[k].end();
           pts[nm] = elmt_stored[k].begin();
           ++nm;
-        } else J *= elmt_stored[k][0];
+        } else
+          J *= elmt_stored[k][0];
       }
-      if (nm == 0) {
+      if (nm == 0)
         t[0] += J;
-      } else {
+      else {
+#if defined(GMM_USES_BLAS)
         BLAS_INT n0 = BLAS_INT(es_end[0] - es_beg[0]);
+        BLAS_INT one = BLAS_INT(1);
+#else
+        size_type n0 = size_type(es_end[0] - es_beg[0]);
+#endif
         base_tensor::const_iterator pts0 = pts[0];
 
         /* very heavy reduction .. takes much time */
         k = nm-1; Vtab[k] = J;
-        BLAS_INT one = BLAS_INT(1);
         scalar_type V;
         do {
           for (V = Vtab[k]; k; --k)
             Vtab[k-1] = V = *pts[k] * V;
           GMM_ASSERT1(pt+n0 <= t.end(), "Internal error");
-	  gmm::daxpy_(&n0, &V, const_cast<double*>(&(pts0[0])), &one,
-		      (double*)&(*pt), &one);
-          pt+=n0;
+#if defined(GMM_USES_BLAS)
+          gmm::daxpy_(&n0, &V, const_cast<double*>(&(pts0[0])), &one,
+                      (double*)&(*pt), &one);
+          pt += n0;
+#else
+          for (k=0; k < n0; ++k)
+            *pt++ += V*pts0[k];
+#endif
           for (k=1; k != nm && ++pts[k] == es_end[k]; ++k)
             pts[k] = es_beg[k];
         } while (k != nm);
@@ -422,7 +433,8 @@ namespace getfem {
 
     void pre_tensors_for_linear_trans(bool volumic) const {
 
-      if ((volumic && volume_computed) || (!volumic && faces_computed)) return;
+      if ((volumic && volume_computed) || (!volumic && faces_computed))
+        return;
       // scalar_type exectime = ftool::uclock_sec();
 
       bgeot::multi_index sizes = pme->sizes(0), mi(sizes.size());
@@ -445,7 +457,7 @@ namespace getfem {
         std::fill(mref.begin()+1, mref.end(), aux);
       }
 
-      if (is_ppi) // pour accelerer, il faudrait prcalculer les drives
+      if (is_ppi) // pour accelerer, il faudrait précalculer les dérivées
       {
         base_poly P(dim, 0), Q(dim, 0), R(dim, 0);
         size_type old_ind = size_type(-1), ind;
@@ -538,7 +550,7 @@ namespace getfem {
       dim_type P = dim_type(dim), N = dim_type(G.nrows());
       short_type NP = short_type(pgt->nb_points());
       fem_interpolation_context ctx(pgp, 0, 0, G, elt,
-				    short_type(ir-1));
+                                    short_type(ir-1));
 
       GMM_ASSERT1(G.ncols() == NP, "dimensions mismatch");
       if (ir > 0) {
@@ -645,7 +657,7 @@ namespace getfem {
                                  bool prefer_comp_on_real_element) {
     dal::pstatic_stored_object_key
       pk = std::make_shared<emelem_comp_key_>(pm, pi, pg,
-					      prefer_comp_on_real_element);
+                                              prefer_comp_on_real_element);
     dal::pstatic_stored_object o = dal::search_stored_object(pk);
     if (o) return std::dynamic_pointer_cast<const mat_elem_computation>(o);
     pmat_elem_computation
