@@ -255,7 +255,10 @@ namespace getfem {
         j1_c(false), j2_c(false), di1_c(false), di2_c(false), di3_c(false),
         dj1_c(false), dj2_c(false), ddi1_c(false), ddi2_c(false),
         ddi3_c(false), ddj1_c(false), ddj2_c(false)
-      { N = gmm::mat_nrows(E); }
+    {
+      N = gmm::mat_nrows(E);
+      i1_=i2_=i3_=j1_=j2_=0.;
+    }
 
   };
 
@@ -2317,7 +2320,7 @@ namespace getfem {
     std::string expr = "((Id(meshdim)+Grad_"+varname+")*(" + adapted_lawname
       + "_PK2(Grad_"+varname+","+params+"))):Grad_" + test_varname;
 
-    return add_nonlinear_generic_assembly_brick
+    return add_nonlinear_term
       (md, mim, expr, region, true, false,
        "Finite strain elasticity brick for " + adapted_lawname + " law");
   }
@@ -2333,7 +2336,7 @@ namespace getfem {
       + "-(" + multname + ")*(Det(Id(meshdim)+Grad_" + varname + ")"
       + "*((Inv(Id(meshdim)+Grad_" + varname + "))':Grad_"
       + test_varname + "))" ;
-    return add_nonlinear_generic_assembly_brick
+    return add_nonlinear_term
       (md, mim, expr, region, true, false,
        "Finite strain incompressibility brick");
   }
