@@ -153,7 +153,7 @@ namespace getfem {
   }
 
   // numerical differantiation of logm
-  // not used becaused it caused some issues and was slower than
+  // not used because it caused some issues and was slower than
   // simply inverting the derivative of expm
   bool logm_deriv(const base_matrix &a, base_tensor &dalog,
                   base_matrix *palog=NULL) {
@@ -1287,11 +1287,11 @@ namespace getfem {
     if (unknowns_type == DISPLACEMENT_AND_PLASTIC_MULTIPLIER) {
       std::string expr = ("("+sigma_np1+"):Grad_Test_"+dispname
                           + "+("+compcond+")*Test_"+xi);
-      return add_nonlinear_generic_assembly_brick
+      return add_nonlinear_term
         (md, mim, expr, region, false, false,
          "Small strain isotropic perfect elastoplasticity brick");
     } else {
-      return add_nonlinear_generic_assembly_brick
+      return add_nonlinear_term
         (md, mim, "("+sigma_np1+"):Grad_Test_"+dispname, region, true, false,
          "Small strain isotropic perfect elastoplasticity brick");
     }
@@ -1592,7 +1592,7 @@ namespace getfem {
       std::string expr, dummy1, dummy2, dummy3;
       build_Simo_Miehe_elastoplasticity_expressions
         (md, unknowns_type, varnames, params, expr, dummy1, dummy2, dummy3);
-      return add_nonlinear_generic_assembly_brick
+      return add_nonlinear_term
         (md, mim, expr, region, true, false, "Simo Miehe elastoplasticity brick");
     } else
       GMM_ASSERT1(false, lawname << " is not a known elastoplastic law");
@@ -2193,15 +2193,10 @@ namespace getfem {
 
     pbrick pbr = std::make_shared<elastoplasticity_brick>(ACP);
 
-    model::termlist tl;
-    tl.push_back(model::term_description
-                 (varname, varname, true));
-    model::varnamelist dl(1, datalambda);
-    dl.push_back(datamu);
-    dl.push_back(datathreshold);
-    dl.push_back(datasigma);
-    dl.push_back(data_previous_disp);
-    model::varnamelist vl(1, varname);
+    model::termlist tl{model::term_description(varname, varname, true)};
+    model::varnamelist
+      dl{datalambda, datamu, datathreshold, datasigma, data_previous_disp},
+      vl{varname};
 
     return md.add_brick(pbr, vl, dl, tl,
                         model::mimlist(1,&mim), region);
