@@ -29,6 +29,7 @@
 #endif
 #include <valarray>
 #include <unistd.h>
+#include <random>
 #include "getfem/bgeot_small_vector.h"
 #include "getfem/getfem_mesh.h"
 
@@ -65,9 +66,9 @@ struct chrono {
 public:
   chrono() { }
   chrono& init() { cpu_=0; return *this; }
-  void tic() { t = float(::clock())/float(CLOCKS_PER_SEC); }
+  void tic() { t = float(gmm::uclock_sec()); }
   chrono& toc() {
-    float t2 = float(::clock())/float(CLOCKS_PER_SEC);
+    float t2 = float(gmm::uclock_sec());
     cpu_ += t2 - t; t = t2; return *this;
   }
   float cpu() const { return cpu_; }
@@ -575,7 +576,7 @@ namespace getfem {
     for (size_type i=0; i < N; ++i) {
       std::vector<V> w, z;
       w = vv;
-      std::random_shuffle(vv.begin(), vv.end());
+      std::shuffle(vv.begin(), vv.end(), std::mt19937());
       z = w;
     }
     cout << " copies : " << c.toc().cpu() << " sec\n";
@@ -601,7 +602,8 @@ namespace getfem {
 //     }
     gmm::lexicographical_less<V, gmm::approx_less<typename V::value_type> > comp;
     c.init().tic();
-    init(vv); std::random_shuffle(vv.begin(), vv.end());
+    init(vv);
+    std::shuffle(vv.begin(), vv.end(), std::mt19937());
     for (size_type i=0; i < N*4; ++i) {
       size_type cnt = 0;
       for (size_type j=vv.size()-1; j > 0; --j) {
@@ -615,7 +617,7 @@ namespace getfem {
     cout << "mesh<base_node> : empty size = " << m.memsize() << "\n";
     init(vv);
     c.init().tic();
-    std::random_shuffle(vv.begin(), vv.end());
+    std::shuffle(vv.begin(), vv.end(), std::mt19937());
     for (size_type i=0; i < N; ++i) {
       m.clear();
       for (size_type j=0; j < vv.size(); ++j) {
@@ -633,7 +635,7 @@ namespace getfem {
     for (size_type j=0; j < w.size(); ++j) {
       w[j] = MICRO_VEC::alloc.allocate(3);
     }
-    std::random_shuffle(w.begin(), w.end());
+    std::shuffle(w.begin(), w.end(), std::mt19937());
     for (size_type j=0; j < w.size(); ++j) {
       MICRO_VEC::alloc.deallocate(w[j]);
     }
@@ -748,7 +750,7 @@ namespace getfem {
       hop2<bgeot::small_vector<char> >();
       hop<bgeot::small_vector<double> >();       
     }
-    bgeot::static_block_allocator::palloc->memstats();
+    bgeot::static_block_allocator().memstats();
     for (size_type i=0; i < 5; ++i) {
       hop2<test::small_vector<double> >();
       //hop2<test::small_vector<unsigned> >();
@@ -757,7 +759,7 @@ namespace getfem {
       hop2<test::small_vector<char> >();
       hop<test::small_vector<double> >(); 
     }
-    test::static_block_allocator::alloc.memstats();
+    test::static_block_allocator().memstats();
   }
   */
 
@@ -779,8 +781,7 @@ namespace getfem {
     //rrun(mv);
     rrun(Sv);
     //rrun(av);
-    if (bgeot::static_block_allocator::palloc)
-      bgeot::static_block_allocator::palloc->memstats();
+    bgeot::static_block_allocator().memstats();
     cout << "sizeof(size_type)=" << sizeof(size_type) 
 	 << ", sizeof(base_node)=" << sizeof(base_node) 
 	 << ", sizeof(base_small_vector)=" << sizeof(base_small_vector) << "\n";
